@@ -50,14 +50,15 @@ int
 main (int argc, char *argv [])
 {
 	GtkWidget *app;
-	GtkWidget *play, *stop, *pause, *properties;
+	GtkWidget *button_play, *stop, *pause, *properties;
 	GtkWidget *hbox, *vbox;
 	GtkWidget *filesel;
 	GtkWidget *slider;
+	GtkWidget *video;
 
 	
 	GstElement *filesrc, *decoder, *audiosink;
-	GstElement *my_thread;
+	GstElement *play;
 
 
 	CallBackData *data = g_new (CallBackData, 1);
@@ -71,47 +72,40 @@ main (int argc, char *argv [])
 	gpe_init (&argc, &argv);
 #endif
 
-	my_thread = gst_thread_new ("my_thread");
- 	filesrc = gst_element_factory_make ("filesrc", "disk_source");
-	decoder = gst_element_factory_make ("mad", "decoder");
 
+	play = gst_element_factory_make ("playbin", "play");
+
+	g_print ("aca llego\n");
 	
-	
-	data->thread = my_thread;
+	data->thread = play;
 	data->filesrc = filesrc;
 	data->decoder = decoder;
 
 
 
-	audiosink = gst_element_factory_make ("osssink", "play_audio");
-
-	gst_bin_add_many (GST_BIN (my_thread), filesrc, decoder, audiosink, NULL);
-
-	if (!gst_element_link_many (filesrc, decoder, audiosink, NULL)){
-	  g_set_error (&err, GST_PLAYER_ERROR, 1, "Failed to start plugins");
-	  return 0;
-	}
-
-	g_signal_connect (G_OBJECT (filesrc), "eos", G_CALLBACK (eos), my_thread);
-	//g_signal_connect (play, "found-tag", G_CALLBACK (cb_found_tag), win);
+	audiosink = gst_element_factory_make ("ximagesink", "video-sink");
 
 
-	if (argc >  1)
-	  select_song (argv [1], filesrc);
+	printf ("%d-%d\n", play, audiosink);
 	
+	g_object_set (play, "video-sink", audiosink, NULL);
+	g_object_set (G_OBJECT (play), "uri", argv[1], NULL);	
+
+	g_signal_connect (G_OBJECT (play), "eos", G_CALLBACK (eos), play);
+
 	app = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
 #ifdef HAVE_GPE
-	play = gpe_button_new_from_stock (GTK_STOCK_MEDIA_PLAY, GPE_BUTTON_TYPE_ICON);
+	button_play = gpe_button_new_from_stock (GTK_STOCK_MEDIA_PLAY, GPE_BUTTON_TYPE_ICON);
 	pause = gpe_button_new_from_stock (GTK_STOCK_MEDIA_PAUSE, GPE_BUTTON_TYPE_ICON);
 	stop = gpe_button_new_from_stock (GTK_STOCK_MEDIA_STOP, GPE_BUTTON_TYPE_ICON);
 #else					  
 #ifdef HAVE_GTK_2_6
-	play = gtk_button_new_from_stock (GTK_STOCK_MEDIA_PLAY);
+	button_play = gtk_button_new_from_stock (GTK_STOCK_MEDIA_PLAY);
 	pause = gtk_button_new_from_stock (GTK_STOCK_MEDIA_PAUSE);
 	stop = gtk_button_new_from_stock (GTK_STOCK_MEDIA_STOP);
 #else
-	play = gtk_button_new_with_label (">");
+	button_play = gtk_button_new_with_label (">");
 	pause = gtk_button_new_with_label ("||");
 	stop = gtk_button_new_with_label ("[]");
 #endif
@@ -120,13 +114,25 @@ main (int argc, char *argv [])
 #ifdef HAVE_GPE
 
 	filesel = gpe_button_new_from_stock (GPE_STOCK_OPEN, GPE_BUTTON_TYPE_ICON);
-	properties = gpe_button_new_from_stock (GPE_STOCK_PROPERTIES. GPE_BUTTON_TYPE_ICON);
+	/*
+	  properties = gpe_button_new_from_stock (GPE_STOCK_PROPERTIES. GPE_BUTTON_TYPE_ICON);
+	*/
 #else
 	filesel = gtk_button_new_from_stock (GTK_STOCK_OPEN);
-	properties = gtk_button_new_from_stock (GTK_STOCK_PROPERTIES);
+	/*
+	  properties = gtk_button_new_from_stock (GTK_STOCK_PROPERTIES);
+
+	*/
 #endif
-	slider = gst_player_timer_new (decoder);
-	
+
+	g_print ("los creo");
+
+	slider = gst_player_timer_new (play);
+	g_print ("eres la culpable");
+	video = gst_player_video_new (audiosink, play); 
+	g_print ("chin chun chan");      
+
+
 	hbox = gtk_hbox_new (TRUE, 0);
 	vbox = gtk_vbox_new (FALSE, 0);
 
@@ -134,22 +140,23 @@ main (int argc, char *argv [])
 
 	gtk_window_set_title (GTK_WINDOW (app), "Siobhan Audio Player");
 
-	gtk_box_pack_start (GTK_BOX (hbox), play, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), button_play, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), pause, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), stop, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), filesel, TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), properties, TRUE, TRUE, 0);
+	/* gtk_box_pack_start (GTK_BOX (hbox), properties, TRUE, TRUE, 0); */
+	gtk_box_pack_start (GTK_BOX (vbox), video, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), slider, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX  (vbox), hbox, FALSE, TRUE, 0);
 
 	gtk_container_add (GTK_CONTAINER (app), vbox);
 	
 	g_signal_connect (G_OBJECT (app), "delete_event", G_CALLBACK (gtk_main_quit),NULL);
-	g_signal_connect (G_OBJECT (play), "clicked", G_CALLBACK (cb_play), data);
-	g_signal_connect (G_OBJECT (pause), "clicked", G_CALLBACK (cb_pause), my_thread);
-	g_signal_connect (G_OBJECT (stop), "clicked", G_CALLBACK (cb_stop), my_thread);
+	g_signal_connect (G_OBJECT (button_play), "clicked", G_CALLBACK (cb_play), data);
+	g_signal_connect (G_OBJECT (pause), "clicked", G_CALLBACK (cb_pause), play);
+	g_signal_connect (G_OBJECT (stop), "clicked", G_CALLBACK (cb_stop), play);
 	g_signal_connect (G_OBJECT (filesel), "clicked", G_CALLBACK (cb_choose), data);
-	
+
 
 	/* 
 	   FIXME:
@@ -160,7 +167,7 @@ main (int argc, char *argv [])
 	  g_signal_connect (G_OBJECT (properties), "clicked", G_CALLBACK (cb_properties), NULL);
 	*/
 
-	g_idle_add (cb_iterate, (gpointer)data);
+	g_idle_add (cb_iterate, (gpointer) data);
 
 
 	gtk_widget_show_all (app);
